@@ -1,4 +1,5 @@
-from typing import Dict
+import logging
+from typing import Dict, Optional
 
 from gql import gql
 
@@ -11,18 +12,20 @@ class EnvVars:
         self.saagie_api = saagie_api
         self.client = saagie_api.client
 
-    def list_globals(self):
+    def list_globals(self, pprint_result: Optional[bool] = True):
         """Get global environment variables
         NB: You can only list environment variables if you have at least the
         viewer role on the platform
-
+        Params
+        ------
+        pprint_result : str
+            Whether to pretty print the results in the console or not
         Returns
         -------
         dict
             Dict of global environment variable on the platform
         """
-        query = gql(GQL_LIST_GLOBAL_ENV_VARS)
-        return self.saagie_api.client.execute(query)
+        return self.saagie_api.client.execute(query=gql(GQL_LIST_GLOBAL_ENV_VARS), pprint_result=pprint_result)
 
     def create_global(self, name: str, value: str, description: str = "", is_password: bool = False) -> Dict:
         """Create a global environment variable
@@ -50,8 +53,10 @@ class EnvVars:
             "isPassword": is_password,
             "scope": "GLOBAL",
         }
-        query = gql(GQL_CREATE_ENV_VAR)
-        return self.saagie_api.client.execute(query, variable_values=params)
+
+        result = self.saagie_api.client.execute(query=gql(GQL_CREATE_ENV_VAR), variable_values=params)
+        logging.info("✅ Environment variable [%s] successfully created", name)
+        return result
 
     def update_global(
         self, name: str, new_name: str = None, value: str = None, description: str = None, is_password: bool = None
@@ -82,10 +87,10 @@ class EnvVars:
             When the variable doesn't already exist
         """
 
-        existing_env_var = self.list_globals()["globalEnvironmentVariables"]
+        existing_env_var = self.list_globals(pprint_result=False)["globalEnvironmentVariables"]
 
         if name not in [env_var["name"] for env_var in existing_env_var]:
-            raise ValueError("Environment variable does not exists")
+            raise ValueError(f"❌ Environment variable {name} does not exists")
 
         params = [d for d in existing_env_var if d["name"] == name][0]
 
@@ -102,9 +107,9 @@ class EnvVars:
         elif is_password == False:
             params["isPassword"] = is_password
 
-        query = gql(GQL_UPDATE_ENV_VAR)
-
-        return self.saagie_api.client.execute(query, variable_values=params)
+        result = self.saagie_api.client.execute(query=gql(GQL_UPDATE_ENV_VAR), variable_values=params)
+        logging.info("✅ Environment variable [%s] successfully updated", name)
+        return result
 
     def create_or_update_global(self, name: str, value: str, description: str = "", is_password: bool = False) -> Dict:
         """
@@ -127,12 +132,13 @@ class EnvVars:
             Dict of created or updated environment variable
         """
 
-        existing_env_var = self.list_globals()["globalEnvironmentVariables"]
+        existing_env_var = self.list_globals(pprint_result=False)["globalEnvironmentVariables"]
         present = name in [env["name"] for env in existing_env_var]
 
         # If variable not present, create it
         if not present:
             return self.create_global(name=name, value=value, description=description, is_password=is_password)
+
         return self.update_global(
             name=name, new_name=None, value=value, description=description, is_password=is_password
         )
@@ -156,18 +162,19 @@ class EnvVars:
             When the given name doesn't correspond to an existing environment
             variable
         """
-        global_envs = self.list_globals()["globalEnvironmentVariables"]
+        global_envs = self.list_globals(pprint_result=False)["globalEnvironmentVariables"]
         global_env = [env for env in global_envs if env["name"] == name]
 
         if len(global_env) == 0:
-            raise ValueError("'name' must be the name of an existing global " "environment variable")
+            raise ValueError("❌ 'name' must be the name of an existing global " "environment variable")
 
         global_env_id = global_env[0]["id"]
 
-        query = gql(GQL_DELETE_ENV_VAR)
-        return self.saagie_api.client.execute(query, variable_values={"id": global_env_id})
+        result = self.saagie_api.client.execute(query=gql(GQL_DELETE_ENV_VAR), variable_values={"id": global_env_id})
+        logging.info("✅ Environment variable [%s] successfully deleted", name)
+        return result
 
-    def list_for_project(self, project_id: str) -> Dict:
+    def list_for_project(self, project_id: str, pprint_result: Optional[bool] = True) -> Dict:
         """Get project environment variables
         NB: You can only list environment variables if you have at least the
         viewer role on the project
@@ -176,14 +183,17 @@ class EnvVars:
         ----------
         project_id : str
             UUID of your project (see README on how to find it)
-
+        pprint_result : str
+            Whether to pretty print the results in the console or not
         Returns
         -------
         dict
             Dict of project environment variables
         """
-        query = gql(GQL_LIST_PROJECT_ENV_VARS)
-        return self.saagie_api.client.execute(query, variable_values={"projectId": project_id})
+
+        return self.saagie_api.client.execute(
+            query=gql(GQL_LIST_PROJECT_ENV_VARS), variable_values={"projectId": project_id}, pprint_result=pprint_result
+        )
 
     def create_for_project(
         self, project_id: str, name: str, value: str, description: str = "", is_password: bool = False
@@ -216,8 +226,10 @@ class EnvVars:
             "isPassword": is_password,
             "scope": "PROJECT",
         }
-        query = gql(GQL_CREATE_ENV_VAR)
-        return self.saagie_api.client.execute(query, variable_values=params)
+
+        result = self.saagie_api.client.execute(query=gql(GQL_CREATE_ENV_VAR), variable_values=params)
+        logging.info("✅ Environment variable [%s] successfully created", name)
+        return result
 
     def update_for_project(
         self,
@@ -257,10 +269,10 @@ class EnvVars:
             When the variable doesn't already exist
         """
 
-        existing_env_var = self.list_for_project(project_id)["projectEnvironmentVariables"]
+        existing_env_var = self.list_for_project(project_id, pprint_result=False)["projectEnvironmentVariables"]
 
         if name not in [env_var["name"] for env_var in existing_env_var]:
-            raise ValueError("Environment variable does not exists")
+            raise ValueError(f"❌ Environment variable {name} does not exists")
 
         params = [d for d in existing_env_var if d["name"] == name][0]
         params["projectId"] = project_id
@@ -277,9 +289,9 @@ class EnvVars:
         elif is_password == False:
             params["isPassword"] = is_password
 
-        query = gql(GQL_UPDATE_ENV_VAR)
-
-        return self.saagie_api.client.execute(query, variable_values=params)
+        result = self.saagie_api.client.execute(query=gql(GQL_UPDATE_ENV_VAR), variable_values=params)
+        logging.info("✅ Environment variable [%s] successfully updated", name)
+        return result
 
     def create_or_update_for_project(
         self, project_id: str, name: str, value: str, description: str = "", is_password: bool = False
@@ -306,7 +318,7 @@ class EnvVars:
             Dict of created or updated environment variable
         """
 
-        existing_env_var = self.list_for_project(project_id)["projectEnvironmentVariables"]
+        existing_env_var = self.list_for_project(project_id, pprint_result=False)["projectEnvironmentVariables"]
         present = name in [env["name"] for env in existing_env_var]
 
         # If variable not present, create it
@@ -344,13 +356,14 @@ class EnvVars:
             When the given name doesn't correspond to an existing environment
             variable inside the given project
         """
-        project_envs = self.list_for_project(project_id)
+        project_envs = self.list_for_project(project_id, pprint_result=False)
         project_env = [env for env in project_envs["projectEnvironmentVariables"] if env["name"] == name]
 
         if len(project_env) == 0:
-            raise ValueError("'name' must be the name of an existing " "environment variable in the given project")
+            raise ValueError("❌ 'name' must be the name of an existing " "environment variable in the given project")
 
         project_env_id = project_env[0]["id"]
 
-        query = gql(GQL_DELETE_ENV_VAR)
-        return self.saagie_api.client.execute(query, variable_values={"id": project_env_id})
+        result = self.saagie_api.client.execute(query=gql(GQL_DELETE_ENV_VAR), variable_values={"id": project_env_id})
+        logging.info("✅ Environment variable [%s] successfully deleted", name)
+        return result
